summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/kswizard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/kswizard.h')
-rw-r--r--kstars/kstars/kswizard.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kstars/kstars/kswizard.h b/kstars/kstars/kswizard.h
index ea570498..27b3010b 100644
--- a/kstars/kstars/kswizard.h
+++ b/kstars/kstars/kswizard.h
@@ -39,13 +39,14 @@ class GeoLocation;
class KSWizard : public KSWizardUI
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
*Constructor
*@p parent pointer to the parent widget
*@p name name for the KSWizard object
*/
- KSWizard( TQWidget *parent=0, const char *name=0 );
+ KSWizard( TQWidget *tqparent=0, const char *name=0 );
/**Destructor */
~KSWizard();
@@ -39,13 +39,14 @@ class GeoLocation;
/**
*Constructor
- *@p parent pointer to the parent widget
+ *@p tqparent pointer to the tqparent widget
*@p name name for the KSWizard object
*/